# VogogoRuby

VogogoRuby is a tool to easily consume [Vogogo's direct APIs](http://dev.vogogo.com/direct_api.html)

## Installation

Add this line to your application's Gemfile:
```ruby
    gem 'vogogo_ruby'
```
And then execute:
```ruby
    $ bundle
```
Or install it yourself as:
```ruby
    $ gem install vogogo_ruby
```
## Usage
1. Create a client instance by providing Vogogo's keys (API_KEY, APP_TOKEN, USER)
```ruby
	vc = VogogoRuby::VogogoDirectAPI.new(API_KEY, APP_TOKEN, USER)
```
2. Consume the API methods

- Create Invoice
```ruby
vc = VogogoRuby::VogogoDirectAPI.new('7098l9kachgdfcb63a8a09acb887f5j7', '456b4dbec13abcb98a8a70acb587f5dd', 'foo@example.com')
data = {customer_ref: 'Mr. Joe Jacob Blow', customer_emails: 'joe@example.com',
					customer_contact_info: '123 Fake ST\nCalgary\nAlberta\n403.987.1231', profile_name: 'Jims Snow Removal',
					profile_emails: 'snow@example.com', profile_contact_info: '403.123.1234', currency: 'CAD',
					amount: '35.00', due_date: '2020-08-14', payable_by: ['CC', 'OBP'],
					message: 'This is your invoice for services rendered.'}
invoice_id = vc.create_invoice data
```

- List Invoices
```ruby
vc = VogogoRuby::VogogoDirectAPI.new('7098l9kachgdfcb63a8a09acb887f5j7', '456b4dbec13abcb98a8a70acb587f5dd', 'foo@example.com')
res = vc.list_invoices
puts 'Amount is: ' + res['objects'][0]['amount'] #Amount is: 35.00
```

- Get Invoice
```ruby
vc = VogogoRuby::VogogoDirectAPI.new('7098l9kachgdfcb63a8a09acb887f5j7', '456b4dbec13abcb98a8a70acb587f5dd', 'foo@example.com')
invoice = vc.get_invoice '87695'
puts 'Currency is: ' + invoice.parsed_response['currency'] #Currency is: CAD
```

- Update Invoice
```ruby
vc = VogogoRuby::VogogoDirectAPI.new('7098l9kachgdfcb63a8a09acb887f5j7', '456b4dbec13abcb98a8a70acb587f5dd', 'foo@example.com')
data = {amount: '50.00'}
res = vc.update_invoice '87695', data
puts res #true
```

- Delete Invoice
```ruby
vc = VogogoRuby::VogogoDirectAPI.new('7098l9kachgdfcb63a8a09acb887f5j7', '456b4dbec13abcb98a8a70acb587f5dd', 'foo@example.com')
res = vc.delete_invoice '87695'
puts res #true
```

For all the rest of the API's methods we use the same approach used in the invoices

```ruby
#Items
vc.create_item data
vc.get_item item_id
vc.list_items
vc.update_item item_id, data
vc.delete_item item_id
#Customers
vc.create_customer data
vc.get_customer customer_id
vc.list_customers
vc.update_customer customer_id, data
vc.delete_customer customer_id
#Customer Accounts
vc.create_customer_account data
vc.get_customer_account customer_account_id
vc.list_customer_accounts
vc.delete_customer_account customer_account_id
#Transactions
vc.post_credit_card_charge data
vc.post_eft_credit data
vc.post_deposit data
vc.post_withdrawal data
```

## Contributing

1. Fork it
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create new Pull Request
