require 'spec_helper'
describe 'Direct API' do
	before(:all) do
		api_key = ENV['API_KEY']
		app_token = ENV['APP_TOKEN']
		user = ENV['USER']
    @vda = VogogoRuby::VogogoDirectAPI.new(api_key, app_token, user)
	end

	it 'Vogogo keys should not be empty' do
		ENV['API_KEY'].should_not be_empty
		ENV['APP_TOKEN'].should_not be_empty
		ENV['USER'].should_not be_empty
	end

	describe '-***Positive***-' do

		describe 'Accounts' do
			it 'should return accounts' do
				ret = @vda.get_accounts
				account_id = ret['objects'][0]['uuid']
		  	ret['objects'].should be_kind_of Array
		  	(@vda.get_account account_id)['uuid'].to_s.should eq account_id.gsub('/', '')
			end
		end

		describe 'Invoice' do
			it 'should create invoice' do
				data = {customer_ref: 'Mr. Joe Jacob Blow', customer_emails: 'joe@example.com',
					customer_contact_info: '123 Fake ST\nCalgary\nAlberta\n403.987.1231', profile_name: 'Jims Snow Removal',
					profile_emails: 'snow@example.com', profile_contact_info: '403.123.1234', currency: 'CAD',
					amount: '35.00', due_date: '2020-08-14', payable_by: ['CC', 'OBP'],
					message: 'This is your invoice for services rendered.'}
				@@invoice_id = @vda.create_invoice data
				@@invoice_id.should_not be_empty
			end

			it 'should get invoice' do
				invoice = @vda.get_invoice @@invoice_id
				invoice['id'].should eq @@invoice_id.gsub('/', '')
			end

			it 'should update invoice' do
				data = {payable_by: ['OBP']}
				ret = @vda.update_invoice @@invoice_id, data
				ret.should be true
			end

			it 'should delete invoice' do
				ret = @vda.delete_invoice @@invoice_id
				ret.should be true
			end
		end

		describe 'Customer' do
			it 'should create customer' do
				data = {customer_ref: 'Mr. API Customer', emails: 'api_customer1@example.com',
				 contact_info: '124 Fake ST\nCalgary\nAlberta\n403.987.1231', subscribe: true, bcc_account_holder: false}
				@@customer_id = @vda.create_customer data
				@@customer_id.should_not be_empty
			end

			it 'should get customer' do
				customer = @vda.get_customer @@customer_id
				customer['id'].should eq @@customer_id.gsub('/', '')
			end

			it 'should update customer' do
				data = {subscribe: false}
				ret = @vda.update_customer @@customer_id, data
				ret.should be true
			end

			it 'should delete customer' do
				ret = @vda.delete_customer @@customer_id
				ret.should be true
			end
		end

		describe 'Item' do
			it 'should create item' do
				data = {unit_price: '25.00', code: 'RPI_G', description: 'Raspbery Pi Model B', quantity: 3}
				@@item_id = @vda.create_item data
				@@item_id.should_not be_empty
			end

			it 'should get item' do
				item = @vda.get_item @@item_id
				item['id'].should eq @@item_id.gsub('/', '')
			end

			it 'should update item' do
				data = {unit_price: '50.00'}
				ret = @vda.update_item @@item_id, data
				ret.should be true
			end

			it 'should delete item' do
				ret = @vda.delete_item @@item_id
				ret.should be true
			end
		end

		describe 'Customer Account' do
			it 'should create customer account' do
				data = {account_number: rand(999999999).to_s, account_type: 'BANK_PA', currency: 'CAD', name: 'API 88887',
				 transit_number: '80002', institution_number: '002'}
				@@customer_account_id = @vda.create_customer_account data
				@@customer_account_id.should_not be_empty
			end

			it 'should get customer account' do
				customer_account = @vda.get_customer_account @@customer_account_id
				customer_account.parsed_response['uuid'].should eq @@customer_account_id.gsub('/', '')
			end

			it 'should delete customer account' do
				ret = @vda.delete_customer_account @@customer_account_id
				ret.should be true
			end
		end
	end

	describe '-***Negative***-' do

		describe 'Accounts' do
			it 'should raise IdentifierError' do
		  	expect { @vda.get_account '' }.to raise_error(IdentifierError)
		  	expect { @vda.get_account nil }.to raise_error(IdentifierError)
			end
		end

		describe 'Invoice' do
			it 'get should raise IdentifierError' do
		  	expect { @vda.get_invoice '' }.to raise_error(IdentifierError)
		  	expect { @vda.get_invoice nil }.to raise_error(IdentifierError)
			end

			it 'create should raise DataHashError' do
		  	expect { @vda.create_invoice '' }.to raise_error(DataHashError)
		  	expect { @vda.create_invoice nil }.to raise_error(DataHashError)
			end

			it 'update should raise DataHashError' do
		  	expect { @vda.update_invoice 'xyz', '' }.to raise_error(DataHashError)
		  	expect { @vda.update_invoice 'xyz', nil }.to raise_error(DataHashError)
			end

			it 'update should raise IdentifierError' do
		  	expect { @vda.update_invoice '', 'xyz' }.to raise_error(IdentifierError)
		  	expect { @vda.update_invoice nil, 'xyz' }.to raise_error(IdentifierError)
			end

			it 'delete should raise IdentifierError' do
		  	expect { @vda.delete_invoice '' }.to raise_error(IdentifierError)
		  	expect { @vda.delete_invoice nil }.to raise_error(IdentifierError)
			end
		end

		describe 'Item' do
			it 'get should raise IdentifierError' do
		  	expect { @vda.get_item '' }.to raise_error(IdentifierError)
		  	expect { @vda.get_item nil }.to raise_error(IdentifierError)
			end

			it 'create should raise DataHashError' do
		  	expect { @vda.create_item '' }.to raise_error(DataHashError)
		  	expect { @vda.create_item nil }.to raise_error(DataHashError)
			end

			it 'update should raise DataHashError' do
		  	expect { @vda.update_item 'xyz', '' }.to raise_error(DataHashError)
		  	expect { @vda.update_item 'xyz', nil }.to raise_error(DataHashError)
			end

			it 'update should raise IdentifierError' do
		  	expect { @vda.update_item '', 'xyz' }.to raise_error(IdentifierError)
		  	expect { @vda.update_item nil, 'xyz' }.to raise_error(IdentifierError)
			end

			it 'delete should raise IdentifierError' do
		  	expect { @vda.delete_item '' }.to raise_error(IdentifierError)
		  	expect { @vda.delete_item nil }.to raise_error(IdentifierError)
			end
		end

		describe 'Customer' do
			it 'get should raise IdentifierError' do
		  	expect { @vda.get_customer '' }.to raise_error(IdentifierError)
		  	expect { @vda.get_customer nil }.to raise_error(IdentifierError)
			end

			it 'create should raise DataHashError' do
		  	expect { @vda.create_customer '' }.to raise_error(DataHashError)
		  	expect { @vda.create_customer nil }.to raise_error(DataHashError)
			end

			it 'update should raise DataHashError' do
		  	expect { @vda.update_customer 'xyz', '' }.to raise_error(DataHashError)
		  	expect { @vda.update_customer 'xyz', nil }.to raise_error(DataHashError)
			end

			it 'update should raise IdentifierError' do
		  	expect { @vda.update_customer '', 'xyz' }.to raise_error(IdentifierError)
		  	expect { @vda.update_customer nil, 'xyz' }.to raise_error(IdentifierError)
			end

			it 'delete should raise IdentifierError' do
		  	expect { @vda.delete_customer '' }.to raise_error(IdentifierError)
		  	expect { @vda.delete_customer nil }.to raise_error(IdentifierError)
			end
		end

		describe 'Customer Account' do
			it 'get should raise IdentifierError' do
		  	expect { @vda.get_customer_account '' }.to raise_error(IdentifierError)
		  	expect { @vda.get_customer_account nil }.to raise_error(IdentifierError)
			end

			it 'create should raise DataHashError' do
		  	expect { @vda.create_customer_account '' }.to raise_error(DataHashError)
		  	expect { @vda.create_customer_account nil }.to raise_error(DataHashError)
			end

			it 'delete should raise IdentifierError' do
		  	expect { @vda.delete_customer_account '' }.to raise_error(IdentifierError)
		  	expect { @vda.delete_customer_account nil }.to raise_error(IdentifierError)
			end
		end
	end

end
